@@ -132,19 +132,13 @@ def _update_agent_requirements(
     default=lambda: _current_config().more_info_url,
     callback=_validate_url,
 )
-@click.option(
-    "--public",
-    prompt=True,
-    default=lambda: _current_config().public,
-    type=click.BOOL,
-)
 @click.option(
     "--requirement",
     multiple=True,
     type=str,
     help="Additional requirements for requirements.txt. Can be specified multiple times.",
 )
-def init_agent(handle, description, entry_point, more_info_url, public, requirement):
+def init_agent(handle, description, entry_point, more_info_url, requirement):
     try:
         current_config = agent_config.load_config()
     except FileNotFoundError:
@@ -153,7 +147,6 @@ def init_agent(handle, description, entry_point, more_info_url, public, requirem
     current_config.description = description
     current_config.entry_point = entry_point
     current_config.more_info_url = more_info_url
-    current_config.public = public
     agent_config.save_config(current_config)
 
     entry_module, _ = entry_point.split(":")
@@ -296,7 +289,7 @@ def _ensure_agent_updated(
             description=config.description,
             more_info_url=config.more_info_url,
             func_url=config.deployment_url,
-            published=config.public,
+            published=config.public or False,
         )
     else:
         agent.update_agent(
@@ -305,7 +298,7 @@ def _ensure_agent_updated(
             description=config.description,
             more_info_url=config.more_info_url,
             func_url=config.deployment_url,
-            published=config.public,
+            published=config.public or False,
         )
 
     return agent
@@ -530,6 +523,7 @@ def _add_text_file_to_tarfile(path: str, text: str, tarball: tarfile.TarFile):
     is_flag=True,
     help="Only publish metadata and refresh, do not redeploy.",
 )
+@click.option("--public", is_flag=True, help="Make the agent public.", default=None)
 @click.option(
     "--validate/--no-validate",
     "validate",
@@ -538,11 +532,22 @@ def _add_text_file_to_tarfile(path: str, text: str, tarball: tarfile.TarFile):
     help="(default enabled) Validate that the agent loads in a local venv before deploying",
 )
 @click.pass_context
-def deploy(ctx, path, metadata_only, validate):
+def deploy(ctx, path, metadata_only, public, validate):
     console = rich_console.Console(soft_wrap=True)
     config = agent_config.load_config(path)
+    if config.public is not None:
+        console.print(
+            "[yellow]Warning:[/] The [blue]`public`[/] option in the agent config is deprecated and will be removed soon."
+        )
+        console.print(
+            "[yellow]Warning:[/] Use [blue]`fixie agent deploy --public`[/] instead."
+        )
+    if public:
+        config.public = True
+
     client: fixieai.FixieClient = ctx.obj.client
     agent_id = f"{client.get_current_username()}/{config.handle}"
+    console.print(f"🦊 Deploying agent [green]{agent_id}[/]...")
 
     agent_dir = os.path.dirname(path) or "."
     if validate:
@@ -606,3 +611,53 @@ def deploy(ctx, path, metadata_only, validate):
     console.print(
         f"Your agent was deployed to {constants.FIXIE_API_URL}/agents/{agent_api.agent_id}\nYou can also chat with your agent using the fixie CLI:\n\n{suggested_command}"
     )
+
+
+@agent.command("publish", help="Make the current agent public.")
+@click.argument("path", callback=_validate_agent_path, required=False)
+@click.pass_context
+def publish(ctx, path):
+    console = rich_console.Console(soft_wrap=True)
+    config = agent_config.load_config(path)
+    if config.public is not None:
+        console.print(
+            "[yellow]Warning:[/] The [blue]`public`[/] option in the agent config is deprecated and will be removed soon."
+        )
+    client: fixieai.FixieClient = ctx.obj.client
+    agent_id = f"{client.get_current_username()}/{config.handle}"
+    console.print(f"🦊 Publishing agent [green]{agent_id}[/]...")
+
+    agent = client.get_agent(agent_id)
+    if not agent.valid:
+        console.print(
+            f"[red]Error:[/] Agent [green]{agent_id}[/] not deployed. Use [blue]`fixie agent deploy`[/] to deploy it."
+        )
+        raise click.Abort()
+    agent.update_agent(published=True)
+
+    console.print(f"Agent [green]{agent_id}[/] has been made public.")
+
+
+@agent.command("unpublish", help="Make the current agent not public.")
+@click.argument("path", callback=_validate_agent_path, required=False)
+@click.pass_context
+def unpublish(ctx, path):
+    console = rich_console.Console(soft_wrap=True)
+    config = agent_config.load_config(path)
+    if config.public is not None:
+        console.print(
+            "[yellow]Warning:[/] The [blue]`public`[/] option in the agent config is deprecated and will be removed soon."
+        )
+    client: fixieai.FixieClient = ctx.obj.client
+    agent_id = f"{client.get_current_username()}/{config.handle}"
+    console.print(f"🦊 Unpublishing agent [green]{agent_id}[/]...")
+
+    agent = client.get_agent(agent_id)
+    if not agent.valid:
+        console.print(
+            f"[red]Error:[/] Agent [green]{agent_id}[/] not deployed. Use [blue]`fixie agent deploy`[/] to deploy it."
+        )
+        raise click.Abort()
+    agent.update_agent(published=False)
+
+    console.print(f"Agent [green]{agent_id}[/] has been made private.")
