@@ -42,11 +42,14 @@ def fixie(ctx):
 fixie.add_command(agent_commands.agent)
 fixie.add_command(auth_commands.auth)
 fixie.add_command(session_commands.session)
+fixie.add_command(auth_commands.user)
 
 # Add aliases for commonly used paths
 fixie.add_command(agent_commands.init_agent, "init")
 fixie.add_command(agent_commands.deploy, "deploy")
 fixie.add_command(agent_commands.serve, "serve")
+fixie.add_command(agent_commands.publish, "publish")
+fixie.add_command(agent_commands.unpublish, "unpublish")
 fixie.add_command(session_commands.new_session, "console")
 
 
